@@ -946,6 +946,8 @@ static void test_network_inet6_stream(void)
 	memset(buffer, 0, sizeof(buffer));
 
 	fd1 = socket(PF_INET6, SOCK_STREAM, 0);
+	if (fd1 == EOF && errno == EAFNOSUPPORT)
+		return;
 	fd2 = socket(PF_INET6, SOCK_STREAM, 0);
 	addr1.sin6_family = AF_INET6;
 	addr1.sin6_addr = in6addr_loopback;
@@ -1077,6 +1079,8 @@ static void test_network_inet6_dgram(void)
 	memset(buffer, 0, sizeof(buffer));
 
 	fd1 = socket(PF_INET6, SOCK_DGRAM, 0);
+	if (fd1 == EOF && errno == EAFNOSUPPORT)
+		return;
 	fd2 = socket(PF_INET6, SOCK_DGRAM, 0);
 	addr1.sin6_family = AF_INET6;
 	addr1.sin6_addr = in6addr_loopback;
