@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2012-2013  Tetsuo Handa
  *
- * Version: 0.2   2016/10/05
+ * Version: 0.2   2021/06/06
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -706,7 +706,8 @@ static const struct {
 	{ "task.uid",                CCS_TYPE_NUMBER,   CCS_TYPE_NUMBER,
 	  CCS_ALL_OK },
 	{ "transition",              CCS_TYPE_ASSIGN,   CCS_TYPE_INVALID,
-	  F(CCS_MAC_EXECUTE) | F(CCS_MAC_AUTO_DOMAIN_TRANSITION) },
+	  F(CCS_MAC_EXECUTE) | F(CCS_MAC_AUTO_DOMAIN_TRANSITION) |
+	  CCS_INET_SOCKET_OK | CCS_UNIX_SOCKET_OK },
 	{ "uid",                     CCS_TYPE_NUMBER,   CCS_TYPE_NUMBER,
 	  F(CCS_MAC_CHOWN) },
 	{ "value",                   CCS_TYPE_STRING,   CCS_TYPE_STRING,
