@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2   2016/10/05
+ * Version: 0.2   2021/09/10
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -41,6 +41,8 @@
 #include <time.h>
 #include <unistd.h>
 #include <stdarg.h>
+#include <sched.h>
+#include <sys/mount.h>
 #include <poll.h>
 
 #define s8 __s8
@@ -50,6 +52,13 @@
 #define true  1
 #define false 0
 
+#ifndef MS_REC
+#define MS_REC          16384
+#endif
+#ifndef MS_PRIVATE
+#define MS_PRIVATE      (1<<18)
+#endif
+
 /***** CONSTANTS DEFINITION START *****/
 
 /***** CONSTANTS DEFINITION END *****/
